// Composables
import { createRouter, createWebHistory } from "vue-router";
import { useUserStore } from "@/store/user";
import { useConfigStore } from "@/store/config";

const routes = [
  {
    path: "/",
    name: "home",
    meta: {
      auth: true,
    },
    // route level code-splitting
    // this generates a separate chunk (Home-[hash].js) for this route
    // which is lazy-loaded when the route is visited.
    component: () => import("@/views/Home.vue"),
  },
  {
    path: "/auth/login",
    name: "login",
    component: () => import("@/views/auth/Login.vue"),
  },
  {
    path: "/libraries",
    name: "libraries",
    component: () => import("@/views/libraries/List.vue"),
  },
  {
    path: "/library/:LibraryId/documents",
    name: "library.documents",
    component: () => import("@/views/documents/List.vue"),
  },
  {
    path: "/library/:LibraryId/query",
    name: "library.query",
    component: () => import("@/views/libraries/Query.vue"),
  },
  {
    path: "/library/:LibraryId/documents/create",
    name: "library.documents.create",
    component: () => import("@/views/documents/Create.vue"),
  },
  {
    path: "/library/:LibraryId/documents/:DocumentId/edit",
    name: "library.documents.edit",
    component: () => import("@/views/documents/Edit.vue"),
  },
  {
    path: "/library/:LibraryId/documents/:DocumentId",
    name: "library.documents.view",
    component: () => import("@/views/documents/View.vue"),
  },
  
];

const router = createRouter({
  history: createWebHistory(process.env.BASE_URL),
  routes,
});

router.beforeEach((to, from) => {

  // get route name
  console.log(from.name, from.fullPath)

  const userStore = useUserStore();
  const configStore = useConfigStore();

  // if (to.matched.length === 0) {
  //   return router.push({ name: "errors.404" });
  // }

  if (to.meta.title) {
    document.title = to.meta.title + " - " + configStore.getAppName();
  } else {
    document.title = configStore.getAppName();
  }

  if (to.meta.auth == true) {
    // validate login state
    if (userStore.jwt_token == null) {
      router.push({ name: "login" });
    }
  } else {
    document.title = configStore.getAppName();
  }

  return true;

});

export default router;
